@@ -1,20 +1,12 @@
 import oss2
 
-from winhye_common.utils.exception_base import WinhyeException, ExceptionCode
+from winhye_common.utils.exception_base import OSSException
 from winhye_common.winhye_logger import logging as logging
 
-__all__ = ["OssBucket", "OSSException"]
+__all__ = ["OssBucket"]
 logger = logging.getLogger()
 
 
-class OSSException(WinhyeException):
-    """OSS exception
-    """
-
-    def __init__(self, message: str):
-        super(OSSException, self).__init__(ExceptionCode.OSS, message)
-
-
 class OssBucket:
     def __init__(self, access_key_id: str, access_key_secret: str, endpoint: str, bucket_name: str):
         """
