@@ -6,7 +6,7 @@ import logging.config
 from .ding_alarm import ding_alarm
 from .filter import HostAddressFilter, RequestAddressFilter, ConcurrentIdFilter, NameFilter
 from .weather import weather_report
-from ..config.config_base import config
+from ..config.config_client import ConfigClient
 
 __all__ = ["logging"]
 
@@ -14,6 +14,7 @@ __all__ = ["logging"]
 REPORT = 100
 logging.addLevelName(REPORT, "REPORT")
 log_dir = "/data/log/flask/"
+LIB_APP_ID = "winhye_common"
 
 
 def logger_report(self, msg: str, weather: bool = False, *args, **kwargs):
@@ -44,11 +45,17 @@ def error(self, msg: str, is_alarm: bool = True, *args, **kwargs):
 
 logging.Logger.report = logger_report
 logging.Logger.error = error
-log_level = config.get_log_level_config()
+
+app_id = os.environ.get("APP_ID", "NOT_EXIST")
+if app_id == "NOT_EXIST":
+    app_id = LIB_APP_ID
+ConfigClient.init(app_id)
+log_conf = ConfigClient.get_configger("winhye_software.common")
+log_config = log_conf.get_group("log_level")
 
 # 是否禁用第三方日志(用户名不为当前用户名)
 filter_list = ["hostname", "source_ip", "concurrent_id"]
-if log_level["third_log"]:
+if eval(log_config.third_log):
     filter_list.append("name")
 
 logging_config = {
@@ -76,22 +83,12 @@ logging_config = {
     "handlers": {
         "console": {
             "class": "logging.StreamHandler",
-            "level": log_level["console"],
+            "level": log_config.console,
             "formatter": "winhye",
             "filters": filter_list
         },
-        # "file": {
-        #     'level': log_level["file"],
-        #     "class": "winhye_common.winhye_handlers.time_handler.MultiProcessSafeTimedRotatingFileHandler",
-        #     "filename": os.path.join(log_dir, "log.log"),
-        #     "formatter": "winhye",
-        #     "filters": filter_list,
-        #     "when": "H",
-        #     "interval": 1,
-        #     "backupCount": 168
-        # }
         "file": {
-            'level': log_level["file"],
+            'level': log_config.file,
             "class": "winhye_common.winhye_handlers.file_handler.MultiprocessHandler",
             "filename": os.path.join(log_dir, "log.log"),
             "formatter": "winhye",
