@@ -1,11 +1,11 @@
 import os
 import sys
 
-PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "src")
+PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
 sys.path.append(PATH)
 print(PATH)
 
-from winhye_common.utils.oss_base import OssBucket
+from src.winhye_common.utils.oss_base import OssBucket
 
 
 def test_oss():
@@ -21,8 +21,8 @@ def test_oss():
         oss_config["endpoint"],
         oss_config["bucket_name"]
     )
-    url = oss_conn.get_url("alarm_3/前方道路已开通请做好行驶准备.mp3", expires=1000)
-    print(f"url: {url}")
+    # url = oss_conn.upload_from_file("123.txt", "123.txt")
+    oss_conn.del_file("123.txt")
 
 
 if __name__ == '__main__':
